package org.rcisoft.business.cmsBanner.controller;


/*固定导入*/

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import org.rcisoft.business.cmsBanner.entity.CmsBanner;
import org.rcisoft.business.cmsBanner.service.CmsBannerService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import jakarta.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
* Created by cy on 2024年3月30日 下午1:51:15.
*/
@RestController
@RequestMapping("/cmsbanner")
public class CmsBannerController extends CyPaginationController<CmsBanner> {


    @Autowired
    private CmsBannerService cmsBannerServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('cms:banner:increase')")
    @CyOpeLogAnno(title = "system-banner管理管理-新增banner管理", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="添加banner管理", description="添加banner管理")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsBanner cmsBanner, BindingResult bindingResult) {
        CyPersistModel data = cmsBannerServiceImpl.persist(cmsBanner);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsBanner);
    }
    @PreAuthorize("@cyPerm.hasPerm('cms:banner:removing')")
    @CyOpeLogAnno(title = "system-banner管理管理-删除banner管理", businessType = CyLogTypeEnum.DELETE)
    @Operation(summary="逻辑删除banner管理", description="逻辑删除banner管理")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true)})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId,CmsBanner cmsBanner) {
        cmsBanner.setBusinessId(Integer.valueOf(businessId));
        CyPersistModel data = cmsBannerServiceImpl.removeLogical(cmsBanner);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:banner:delete')")
    @CyOpeLogAnno(title = "system-banner管理管理-删除banner管理", businessType = CyLogTypeEnum.DELETE)
    @Operation(summary="删除banner管理", description="删除banner管理")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true)})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,CmsBanner cmsBanner) {
        cmsBanner.setBusinessId(Integer.valueOf(businessId));
        CyPersistModel data = cmsBannerServiceImpl.remove(cmsBanner);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:banner:modifications')")
    @CyOpeLogAnno(title = "system-banner管理管理-修改banner管理", businessType = CyLogTypeEnum.UPDATE)
    @Operation(summary="修改banner管理", description="修改banner管理")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = false)})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid CmsBanner cmsBanner, BindingResult bindingResult) {
        cmsBanner.setBusinessId(Integer.valueOf(businessId));
        CyPersistModel data = cmsBannerServiceImpl.merge(cmsBanner);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsBanner);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:banner:singleSearch')")
    @CyOpeLogAnno(title = "system-banner管理管理-查询banner管理", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询单一banner管理", description="查询单一banner管理")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true)})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsBannerServiceImpl.findById(businessId));
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:banner:search')")
    @CyOpeLogAnno(title = "system-banner管理管理-查询banner管理", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询banner管理集合", description="查询banner管理集合")
    @GetMapping(value = "/queryCmsBanners")
    public CyResult queryCmsBanners(CmsBanner cmsBanner) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            cmsBannerServiceImpl.findAll(cmsBanner));
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:banner:pageSearch')")
    @CyOpeLogAnno(title = "system-banner管理管理-查询banner管理", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询banner管理集合", description="分页查询banner管理集合")
    @GetMapping(value = "/queryCmsBannerByPagination")
    public CyGridModel listByPagination(CmsBanner cmsBanner) {
        cmsBannerServiceImpl.findAllByPagination(getPaginationUtility(), cmsBanner);
        return getGridModelResponse();
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:banner:derive')")
    @CyOpeLogAnno(title = "system-banner管理管理-查询banner管理", businessType = CyLogTypeEnum.EXPORT)
    @Operation(summary = "导出banner管理信息", description = "导出banner管理信息")
    @GetMapping(value = "/export")
    public void outCmsBanner(HttpServletResponse response, CmsBanner cmsBanner, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="banner管理信息.xls";break;
            case "1": excelName="banner管理信息.xlsx";break;
            case "2": excelName="banner管理信息.csv";break;
        }
        List<CmsBanner> cmsBannerList = cmsBannerServiceImpl.export(cmsBanner);
        CyEpExcelUtil.exportExcel(cmsBannerList, "banner管理信息", "banner管理信息", CmsBanner.class, excelName, response);
    }
}
