package org.rcisoft.business.cmsBanner.service.impl;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.cmsBanner.dao.CmsBannerRepository;
import org.rcisoft.business.cmsBanner.entity.CmsBanner;
import org.rcisoft.business.cmsBanner.service.CmsBannerService;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by cy on 2024年3月30日 下午1:51:15.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsBannerServiceImpl extends ServiceImpl<CmsBannerRepository, CmsBanner> implements CmsBannerService {

    @Autowired
    private Global global;
    /**
    * 保存 banner管理
    * @param cmsBanner
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsBanner cmsBanner){
        //增加操作
        int line = baseMapper.insert(cmsBanner);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            cmsBanner.getBusinessId()+"的banner管理信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 banner管理
    * @param cmsBanner
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsBanner cmsBanner){
        int line = baseMapper.realDelete(cmsBanner);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            cmsBanner.getBusinessId()+"的banner管理信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 banner管理
    * @param cmsBanner
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(CmsBanner cmsBanner){
        cmsBanner.setDeleted();
        int line = baseMapper.deleteById(cmsBanner);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                cmsBanner.getBusinessId()+"的banner管理信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 banner管理
    * @param cmsBanner
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsBanner cmsBanner){
        int line = baseMapper.updateById(cmsBanner);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ cmsBanner.getBusinessId()+"的banner管理信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 banner管理
    * @param id
    * @return
    */
    @Override
    public CmsBanner findById(String id){
        CmsBanner banner = baseMapper.selectByIdWithUrl(id);
        if (banner.getPath()!=null){
            banner.setPath(global.getBase_Discovery()+banner.getPath());
        }
        return banner;
    }

    /**
    * 分页查询 banner管理
    * @param cmsBanner
    * @return
    */
    @Override
    public IPage<CmsBanner> findAllByPagination(CyPageInfo<CmsBanner> paginationUtility,
                                                CmsBanner cmsBanner){
        IPage<CmsBanner> result = baseMapper.queryCmsBannersPaged(paginationUtility,cmsBanner);
        List<CmsBanner> cmsBannerList = result.getRecords();
        for (CmsBanner banner : cmsBannerList){
            if (banner.getPath()!=null){
                banner.setPath(global.getBase_Discovery()+banner.getPath());
            }
        }
        return result;

    }

    /**
    * 查询list banner管理
    * @param cmsBanner
    * @return
    */
    @Override
    public List<CmsBanner> findAll(CmsBanner cmsBanner){
        return baseMapper.queryCmsBanners(cmsBanner);

    }

    /**
    * 导出banner管理
    * @return
    */
    @Override
    public List<CmsBanner> export(CmsBanner cmsBanner) {
        List<CmsBanner> cmsBannerList = baseMapper.queryCmsBanners(cmsBanner);
        return cmsBannerList;
    }

}
